@@ -1,10 +1,10 @@
-#! /bin/bash
+#! /bin/sh
 #
 # Initial policy generator.
 #
 # Copyright (C) 2005-2007  NTT DATA CORPORATION
 #
-# Version: 1.5.0   2007/09/20
+# Version: 1.5.1   2007/10/19
 #
 
 cd ${0%/*}
@@ -22,6 +22,12 @@ do
 	shift
 done
 
+# Verify realpath works.
+if ! realpath -n / > /dev/null; then
+    echo "Can't execute program. Please make sure you installed correct package."
+    exit 1
+fi
+
 make_exception() {
 	#
 	# Make /sbin/modprobe and /sbin/hotplug as initializers, for they can be called by untrusted programs.
@@ -48,7 +54,7 @@ make_exception() {
 		do
 			for j in `find $i | awk -F / ' { print NF-1 }'`
 			do
-				echo -n "file_pattern "$i; for ((k = 2; k < $j; k = $k + 1)); do echo -n '/\*'; done; echo
+				echo -n "file_pattern "$i; for k in `seq 3 $j`; do echo -n '/\*'; done; echo
 			done
 		done | grep -F '\' | sort | uniq
 	fi
@@ -72,12 +78,12 @@ make_exception() {
 	#
 	for i in `find /usr/share/man/ -type f | awk -F / ' { print NF }' | sort | uniq`
 	do
-		echo -n "file_pattern /usr/share/man"; for ((j = 4; j < $i; j = $j + 1)); do echo -n '/\*'; done; echo
+		echo -n "file_pattern /usr/share/man"; for j in `seq 5 $i`; do echo -n '/\*'; done; echo
 	done
       
 	for i in `find /usr/X11R6/man/ -type f | awk -F / ' { print NF }' | sort | uniq`
 	do
-		echo -n "file_pattern /usr/X11R6/man"; for ((j = 4; j < $i; j = $j + 1)); do echo -n '/\*'; done; echo
+		echo -n "file_pattern /usr/X11R6/man"; for j in `seq 5 $i`; do echo -n '/\*'; done; echo
 	done
 	
 	#
@@ -87,6 +93,8 @@ make_exception() {
 	do
 		[ -d $i/ -a ! -L $i ] && echo 'file_pattern '$i'/\*'
 	done
+	[ -d /var/spool/postfix/ ] && echo 'file_pattern /var/spool/postfix/deferred/\x/'
+	[ -d /var/spool/postfix/ ] && echo 'file_pattern /var/spool/postfix/deferred/\x/\X'
 	
 	#
 	# Make patterns for man(1).
@@ -343,7 +351,7 @@ make_exception() {
 	fi
 	
 	#
-	# Make patterns for acacron(8).
+	# Make patterns for anacron(8).
 	#
 	ANACRON_PATH=`which anacron`
 	if [ -n "$ANACRON_PATH" ]; then
@@ -392,12 +400,15 @@ make_exception() {
 		echo 'file_pattern /var/run/nscd/db\?\?\?\?\?\?'
 	fi
 	
+	echo 'file_pattern /tmp/ib\?\?\?\?\?\?'
+	echo 'file_pattern /tmp/PerlIO_\?\?\?\?\?\?'
+
 	#
 	# Make /var/log/ directory not rewritable by default.
 	#
 	for i in `find /var/log/ -type f | awk -F / ' { print NF }' | sort | uniq`
 	do
-		echo -n "deny_rewrite /var/log"; for ((j = 3; j < $i; j = $j + 1)); do echo -n '/\*'; done; echo
+		echo -n "deny_rewrite /var/log"; for j in `seq 4 $i`; do echo -n '/\*'; done; echo
 	done
 }
 
